# coding=utf-8
from django import forms
from django.conf import settings
from django.core.urlresolvers import reverse
from django.forms import Textarea
from django.utils.safestring import mark_safe

editorBasePath = '%s%s' % (settings.STATIC_URL, 'zui/lib/kindeditor/')


class KindEditor(Textarea):
    scheme = 'default'
    toolbar = 'mini'

    def __init__(self, attrs=None):
        attrs = attrs or {}
        attrs['rel'] = 'kind'
        if attrs and 'toolbar' in attrs:
            self.toolbar = attrs['toolbar']
        super(KindEditor, self).__init__(attrs)

    def _media(self):
        use_require = getattr("settings", "KINDEDITOR_USE_REQUERYJS", False)
        if use_require:
            return forms.Media(css={'all': ('%skindeditor.min.css' % editorBasePath,
                                            '%sthemes/default/default.css' % editorBasePath,)})
        else:
            return forms.Media(css={'all': ('%skindeditor.min.css' % editorBasePath,
                                            '%sthemes/default/default.css' % editorBasePath,)},
                               js=('%skindeditor.min.js' % editorBasePath,))

    media = property(_media)

    def _get_toolbar_items(self):
        if self.toolbar == 'mini':
            return """
            ,items : ['fontname', 'fontsize', '|', 'forecolor', 'hilitecolor', 'bold', 'italic', 'underline',
            'removeformat', '|', 'justifyleft', 'justifycenter', 'justifyright', 'insertorderedlist',
            'insertunorderedlist', '|', 'emoticons', 'image', 'link', '|','about']
            """
        elif self.toolbar == 'small':
            return """
            ,items : ['bold', 'italic', 'underline', 'strikethrough', 'removeformat','|','insertorderedlist', 'insertunorderedlist',
                   'forecolor', 'hilitecolor', 'fontname', 'fontsize','subscript','superscript',  '|', 'link', 'unlink', 'emoticons',
                   'shcode', 'image', 'flash', 'quote', '|','about']"""
        else:
            return """,items: %s""" % self.toolbar

    def _get_kind_attrs(self):
        return ''.join((
            ',width:"%s"' % (self.attrs['width'] if 'width' in self.attrs else '100%'),
            ',height:%s' % self.attrs['height'] if 'height' in self.attrs else '',
            self._get_toolbar_items()
        ))

    def render(self, name, value, attrs=None):
        use_require = getattr("settings", "KINDEDITOR_USE_REQUERYJS", False)
        if use_require:
            js_staff = '''<script type="text/javascript">
            require(["kindeditor"],function(){ %s });
            </script>
            '''
        else:
            js_staff = '''<script type="text/javascript">
            %s
            </script>
            '''
        js = u'''
                 KindEditor.lang('zh_CN');
                var editor_{name};
                var is_{name}_creating = true;
                KindEditor.ready(function(K) {{
                    editor_{name} = K.create('#id_{name}',{{
                        themeType:'{schema}'{attrs},
                        filterMode:false,
                        uploadJson:'{upload_url}',
                        afterChange: function () {{
                            this.sync();
                            if(is_{name}_creating)
                                is_{name}_creating = false;
                            else
                                $('#id_{name}').change();
                        }},
                        afterBlur: function () {{
                            this.sync();
                            $('#id_{name}').change();
                        }}
                    }});
                }});
        '''.format(name=name, schema=self.scheme,
                   attrs=self._get_kind_attrs(), upload_url=reverse('kind_upload'))
        js = js_staff % js
        textarea = super(KindEditor, self).render(name, value, attrs)
        textarea += js
        return mark_safe(textarea)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.contrib.admin.widgets import AdminFileWidget
from django.forms import (
    HiddenInput, FileInput, CheckboxSelectMultiple, Textarea, TextInput,
    PasswordInput
)
from django.forms.widgets import CheckboxInput

from .zui import (
    get_zui_setting, get_form_renderer, get_field_renderer,
    get_formset_renderer
)
from .text import text_concat, text_value
from .exceptions import BootstrapError
from .utils import add_css_class, render_tag, split_css_classes
from .components import render_icon


FORM_GROUP_CLASS = 'form-group'


def render_formset(formset, **kwargs):
    """
    Render a formset to a Bootstrap layout
    """
    renderer_cls = get_formset_renderer(**kwargs)
    return renderer_cls(formset, **kwargs).render()


def render_formset_errors(formset, **kwargs):
    """
    Render formset errors to a Bootstrap layout
    """
    renderer_cls = get_formset_renderer(**kwargs)
    return renderer_cls(formset, **kwargs).render_errors()


def render_form(form, **kwargs):
    """
    Render a form to a Bootstrap layout
    """
    renderer_cls = get_form_renderer(**kwargs)
    return renderer_cls(form, **kwargs).render()


def render_form_errors(form, type='all', **kwargs):
    """
    Render form errors to a Bootstrap layout
    """
    renderer_cls = get_form_renderer(**kwargs)
    return renderer_cls(form, **kwargs).render_errors(type)


def render_field(field, **kwargs):
    """
    Render a field to a Bootstrap layout
    """
    renderer_cls = get_field_renderer(**kwargs)
    return renderer_cls(field, **kwargs).render()


def render_label(content, label_for=None, label_class=None, label_title=''):
    """
    Render a label with content
    """
    attrs = {}
    if label_for:
        attrs['for'] = label_for
    if label_class:
        attrs['class'] = label_class
    if label_title:
        attrs['title'] = label_title
    return render_tag('label', attrs=attrs, content=content)


def render_button(
        content, button_type=None, icon=None, button_class='', size='',
        href='', name=None, value=None):
    """
    Render a button with content
    """
    attrs = {}
    classes = add_css_class('btn', button_class)
    size = text_value(size).lower().strip()
    if size == 'xs':
        classes = add_css_class(classes, 'btn-xs')
    elif size == 'sm' or size == 'small':
        classes = add_css_class(classes, 'btn-sm')
    elif size == 'lg' or size == 'large':
        classes = add_css_class(classes, 'btn-lg')
    elif size == 'md' or size == 'medium':
        pass
    elif size:
        raise BootstrapError(
            'Parameter "size" should be "xs", "sm", "lg" or ' +
            'empty ("{}" given).'.format(size))
    if button_type:
        if button_type == 'submit':
            if not any([c.startswith('btn-') for c in split_css_classes(classes)]):
                classes = add_css_class(classes, 'btn-primary')
        elif button_type not in ('reset', 'button', 'link'):
            raise BootstrapError(
                'Parameter "button_type" should be "submit", "reset", ' +
                '"button", "link" or empty  ("{}" given).'.format(button_type))
        attrs['type'] = button_type
    attrs['class'] = classes
    icon_content = render_icon(icon) if icon else ''
    if href:
        attrs['href'] = href
        tag = 'a'
    else:
        tag = 'button'
    if name:
        attrs['name'] = name
    if value:
        attrs['value'] = value
    return render_tag(
        tag, attrs=attrs, content=text_concat(
            icon_content, content, separator=' '))


def render_field_and_label(
        field, label, field_class='', label_for=None, label_class='',
        layout='', **kwargs):
    """
    Render a field with its label
    """
    if layout == 'horizontal':
        if not label_class:
            label_class = get_zui_setting('horizontal_label_class')
        if not field_class:
            field_class = get_zui_setting('horizontal_field_class')
        if not label:
            label = '&#160;'
        label_class = add_css_class(label_class, 'control-label')
    html = field
    if field_class:
        html = '<div class="{klass}">{html}</div>'.format(
            klass=field_class, html=html)
    if label:
        html = render_label(
            label, label_for=label_for, label_class=label_class) + html
    return html


def render_form_group(content, css_class=FORM_GROUP_CLASS):
    """
    Render a Bootstrap form group
    """
    return '<div class="{klass}">{content}</div>'.format(
        klass=css_class,
        content=content,
    )


def is_widget_required_attribute(widget):
    """
    Is this widget required?
    """
    if not get_zui_setting('set_required'):
        return False
    if not widget.is_required:
        return False
    if isinstance(
            widget, (
                AdminFileWidget, HiddenInput, FileInput,
                CheckboxInput, CheckboxSelectMultiple)):
        return False
    return True


def is_widget_with_placeholder(widget):
    """
    Is this a widget that should have a placeholder?
    Only text, search, url, tel, e-mail, password, number have placeholders
    These are all derived form TextInput, except for Textarea
    """
    # PasswordInput inherits from Input in Django 1.4.
    # It was changed to inherit from TextInput in 1.5.
    return isinstance(widget, (TextInput, Textarea, PasswordInput))



# coding=utf-8


def get_remote_addr(request):
    remote_addr = request.META.get('HTTP_X_FORWARDED_FOR', request.META['REMOTE_ADDR'])
    return remote_addr.split(',')[0]


def get_form_error_message(form):
    errors = form.errors
    result = []
    for k in errors:
        result.append(u'\r\n'.join(errors[k]))
    return u'\r\n'.join(result)



from django import forms
from django.test import TestCase

# Create your tests here.
from scaffold_toolkit.forms.kindeditor import KindEditor


class KindForm(forms.Form):
    editor = forms.CharField(widget=KindEditor)


class KindeditorTest(TestCase):
    def test_form(self):
        form = KindForm()
        # print(form.media)
        e = KindEditor()
        print(e.render('editor', ''))



#coding=utf-8
import logging


class ExceptionLoggingMiddleware(object):
    def process_exception(self, request, exception):
        logging.exception('Exception handling request for ' + request.path)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class BootstrapException(Exception):
    """
    Any exception from this package
    """
    pass


class BootstrapError(BootstrapException):
    """
    Any exception that is an error
    """
    pass



#coding=utf-8
from django import template
from django.conf import settings as django_settings

register = template.Library()


@register.simple_tag
def settings(name):
    return getattr(django_settings, name, "")


@register.assignment_tag
def settings_value(name):
    return getattr(django_settings, name, "")


# coding=utf-8
def filemd5(filename):
    # 计算hash
    import hashlib

    BLOCKSIZE = 65536
    hasher = hashlib.md5()
    with open(filename, 'rb') as afile:
        buf = afile.read(BLOCKSIZE)
        while len(buf) > 0:
            hasher.update(buf)
            buf = afile.read(BLOCKSIZE)
    return hasher.hexdigest()



# coding=utf-8
from django.forms import Widget, forms
from django.utils.safestring import mark_safe
from django.utils.html import escapejs
from django.conf import settings


class UMEditor(Widget):
    scheme = 'default'
    toolbar = 'mini'

    def __init__(self, attrs=None):
        attrs = attrs or {}
        attrs.update(style="display: none")
        attrs['height'] = attrs.get('height', '100')
        attrs['rel'] = 'kind'
        if attrs and 'scheme' in attrs:
            self.scheme = attrs['scheme']
        if attrs and 'toolbar' in attrs:
            self.toolbar = attrs['toolbar']
        if 'width' in attrs:
            attrs['minFrameWidth'] = attrs['width']
        if 'height' in attrs:
            attrs['minFrameHeight'] = attrs['height']
        super(UMEditor, self).__init__(attrs)

    editorBasePath = '%s%s' % (settings.STATIC_URL, 'zui/dist/lib/umeditor/')

    def _media(self):

        css = {'all': ('%s%s' % (self.editorBasePath, 'themes/default/css/umeditor.min.css'),)}

        return forms.Media(js=('%s%s' % (self.editorBasePath, 'umeditor.config.js'),
                               '%s%s' % (self.editorBasePath, 'umeditor.min.js'),
                               '%s%s' % (self.editorBasePath, 'lang/zh-cn/zh-cn.js'),
                               ),
                           css=css
                           )

    media = property(_media)

    def _get_toolbar_items(self):
        if self.toolbar == 'mini':
            return """
            ,toolbar : ['bold italic underline strikethrough removeformat |',
                      'insertorderedlist insertunorderedlist forecolor',
                      'backcolor fontfamily fontsize subscript superscript |',
                      'link unlink emotion formula']
            """
        elif self.toolbar == 'small':
            return """
            ,toolbar: [
                        'cleardoc | bold italic underline strikethrough removeformat', 
                        '| insertorderedlist insertunorderedlist forecolor backcolor', 
                        'fontfamily fontsize subscript superscript | link unlink',
                        'emotion image video formula'
                        ]
            """
        elif self.toolbar == 'tiny':
            return """
            ,toolbar: [
                        'bold italic underline strikethrough removeformat',
                        '| insertorderedlist insertunorderedlist forecolor backcolor',
                        'fontfamily fontsize subscript superscript',
                        'image formula'
                        ]
            """
        else:
            return """
            ,toolbar:[
                'source | undo redo | bold italic underline strikethrough | superscript subscript | forecolor backcolor | removeformat |',
                'insertorderedlist insertunorderedlist | selectall cleardoc paragraph | fontfamily fontsize',
                '| justifyleft justifycenter justifyright justifyjustify |',
                'link unlink | emotion image video  | map',
                '| horizontal print preview  fullscreen', 'drafts', 'formula']
            """

    def _get_umeditor_attrs(self):
        return ''.join((
            ',initialFrameWidth:"%s"' % self.attrs['width'] if 'width' in self.attrs else '',
            ',initialFrameHeight:"%s"' % self.attrs['height'] if 'height' in self.attrs else '',
            ',minFrameWidth:"%s"' % self.attrs['minFrameWidth'] if 'minFrameWidth' in self.attrs else '',
            ',minFrameHeight:"%s"' % self.attrs['minFrameHeight'] if 'minFrameHeight' in self.attrs else '',
            self._get_toolbar_items()
        ))

    def render(self, name, value, attrs=None):
        """
            数学公式格式: <span data-latex="公式元数据"> static html <span>
        """
        textarea = u'''
            <script id="id_{name}" name="{name}" type="text/plain"></script>

            <script type="text/javascript">
            $(document).ready(function(){{

                // 输出规则： static html替换iframe, 元数据保存在data-latex
                function formulaEditToStatic(root){{
                    var um = this;
                    $.each(root.getNodesByTagName('iframe'), function (i, node) {{
                        if (node.hasClass('mathquill-embedded-latex')) {{
                            var formulaEle = $('div.main', $(um.body).find('iframe')[i].contentWindow.document);
                            if (formulaEle.length == 0) return ;

                            var formulaHtml = $.trim(formulaEle.html());
                            var formulaNode = UM.htmlparser(formulaHtml);
                            var formulaFirChild = formulaNode.firstChild();

                            formulaFirChild.tagName = 'span';
                            formulaFirChild.setAttr('data-latex', node.getAttr('data-latex'));
                            formulaFirChild.removeClass("mathquill-editable");

                            node.parentNode.replaceChild(formulaNode, node);
                        }}
                    }});
                }}

                // 输入规则：静态class修改为可编辑class，元数据替换标签内容.
                function modifyFormulaInfo(root){{
                    $.each(root.getNodesByTagName('span'), function (i, node) {{
                        if (node.hasClass('mathquill-rendered-math') && node.getAttr('data-latex')) {{
                            node.addClass('mathquill-embedded-latex');
                            node.innerHTML(node.getAttr('data-latex'));
                        }}
                    }});
                }}

                if (!UM.customFormulaReady){{

                    var originFormulaPlugin = UM.plugins['formula'];
                    UM.plugins['formula'] = function () {{
                        this.addOutputRule(formulaEditToStatic);
                        this.addInputRule(modifyFormulaInfo);
                        originFormulaPlugin.call(this);
                    }};

                    // formula 添加 π、↑, 转义"<"为"&lt;"
                    var originRegisterWidget = UM.registerWidget;
                    UM.registerWidget = function(name,pro,cb){{
                        if (name === "formula"){{
                            pro.sourceData.formula.letter.push('{{/}}pi');
                            pro.sourceData.formula.symbol.push('↑');
                            var originInsertLatex = pro.insertLatex;
                            pro.insertLatex = function (latex) {{
                                latex === "<" && (latex = "&lt;");
                                originInsertLatex.call(pro, latex);
                            }}
                        }}
                        originRegisterWidget(name, pro, cb);
                    }}

                    UM.customFormulaReady = true;
                }}

                var um = UM.getEditor('id_{name}',
                    {{
                        UMEDITOR_HOME_URL: "/static/zui/dist/lib/umeditor/",
                        theme: '{theme}'
                        {style},
                        imageUrl: '{upload_url}',
                        imagePath: "",
                        autoHeightEnabled: true,
                        imageFieldName: 'imgFile',
                        autoClearinitialContent: false, //自动清除编辑器初始内容会直接附值，跳过setcontent中的inputrule
                        initialStyle: 'p{{font-size: 13px}}',
                    }}
                );
                um.setContent('{value}');
                um.addListener('blur selectionchange', function(){{
                    this.sync();
                }});
                // 初始化时，输入规则生成的iframe中的script的执行会慢于自定义输出规则，导致输出规则查找不到相应元素, 等iframe
                // 加载完成再同步
                $('iframe').load(function(){{
                    um.sync();
                }});
            }});
        </script>
        '''.format(name=name, theme=self.scheme,
                   style=self._get_umeditor_attrs(),
                   upload_url="/kind_upload/",
                   value=value and escapejs(value) or u'')
        return mark_safe(textarea)



#coding=utf-8
from django.utils import translation


def convert_datetime_python_to_javascript(input_format):
    input_format = input_format.replace('%Y', 'YYYY')
    input_format = input_format.replace('%m', 'MM')
    input_format = input_format.replace('%d', 'DD')
    input_format = input_format.replace('%H', 'h')
    input_format = input_format.replace('%M', 'm')
    input_format = input_format.replace('%S', 's')
    return input_format


def get_language():
    language = translation.get_language()
    if '-' in language:
        parts = language.split('-')
        parts[1] = parts[1].upper()
        return '_'.join(parts)
    else:
        return language



# coding=utf-8
import json
import datetime
from django.core.exceptions import FieldDoesNotExist, ValidationError

from django.core.serializers.json import DjangoJSONEncoder
from django.db import models
import six


def to_dict(obj, excludes=None):
    """
    转换为dict类型
    :param obj: 
    :return:
    """
    d = {}
    excludes = excludes or []

    def dump_submodel(sub_obj):
        sd = {}
        for fd in sub_obj._meta.fields:
            if isinstance(fd, models.DurationField):
                sd[fd.name] = fd.value_to_string(fd)
            elif not isinstance(fd, models.ManyToManyField):
                sd[fd.name] = fd.value_to_string(fd)
        return sd

    for field in obj._meta.fields:
        if field.name in excludes:
            continue
        if isinstance(field, models.ForeignKey):
            d['{}_id'.format(field.name)] = getattr(obj, '%s_id' % field.name)
        elif isinstance(field, models.ManyToManyField):
            field_attr = getattr(obj, field.name, field.get_attname())
            d[field.name] = [dump_submodel(o) for o in field_attr.all()]
        elif isinstance(field, models.FileField):
            if getattr(obj, field.name):
                d[field.name] = getattr(obj, field.name).name
                d['%s_url' % field.name] = getattr(obj, field.name).url
        elif isinstance(field, models.DurationField):
            d[field.name] = field.value_to_string(obj)
        else:
            d[field.name] = getattr(obj, field.name)
    return d


def to_json(obj):
    """
    转换为json
    :param obj:
    :return:
    """
    return json.dumps(to_dict(obj), cls=DjangoJSONEncoder)


def from_dict(d, cls):
    """
    从dict恢复
    :param d:
    :param cls:
    :return:
    """
    if 'id' in d:
        try:
            obj = cls.objects.get(id=d['id'])
        except cls.DoesNotExist:
            obj = cls()
    else:
        obj = cls()
    for k, v in d.iteritems():
        if hasattr(obj, k) and not isinstance(v, list):
            try:
                field = obj._meta.get_field(k)

                if isinstance(field, models.DurationField):
                    if v == '':
                        setattr(obj, k, datetime.timedelta())
                    else:
                        value = field.to_python(v)
                        setattr(obj, k, value)
                else:
                    value = field.to_python(v)
                    setattr(obj, k, value)
            except (FieldDoesNotExist, ValidationError):
                pass
    return obj


def from_json(jso, cls):
    """
    从json转换
    :param jso:
    :param cls:
    :return:
    """
    d = json.loads(jso) if isinstance(jso, six.string_types) else jso
    return from_dict(d, cls)




# coding=utf-8
from django.conf.urls import url
from django.views.generic import TemplateView
from scaffold_toolkit.views import kindeditor_upload_file, tag_suggestion

urlpatterns = [url(r'^kind_upload/$', kindeditor_upload_file, name='kind_upload'),
               url(r'^dialog-success/$', TemplateView.as_view(template_name='common/dialog_success.html'),
                   name='dialog_success'),
               url(r'^tag_suggestion/$', tag_suggestion, name='tag_suggestion'),
               ]



#coding=utf-8
from django.apps import apps
from django.conf import settings
from django.conf.urls import patterns, include, url
from importlib import import_module


def load_admins():
    for app in settings.INSTALLED_APPS:
        try:
            import_module('%s.admin' % app)

        except ImportError:
            pass


def discover_admin_urls():
    """
    自动发现管理模块的url
    :return:
    """
    urlpatterns = []
    for app in settings.INSTALLED_APPS:
        try:
            import_module('%s.admin.urls' % app)
            urlpatterns += patterns("",
                                    url(r'^admin/%s/' % app, include('%s.admin.urls' % app)))
        except ImportError:
            pass
    return urlpatterns


def bootstrap():
    load_admins()


# coding=utf-8
import json
import datetime
from braces.views import AjaxResponseMixin, JSONResponseMixin, PermissionRequiredMixin, LoginRequiredMixin
from django.core.files.storage import default_storage
from django.shortcuts import resolve_url
from django.views.decorators.csrf import csrf_exempt
from django.views.decorators.http import require_http_methods
import os
from django.conf import settings
from django.http import HttpResponse, JsonResponse
from django.views.generic import View, FormView
from scaffold_toolkit.utilities.misc import get_form_error_message
import shortuuid
from braces.views import OrderableListMixin as olm


class AjaxFormView(JSONResponseMixin, AjaxResponseMixin, FormView):
    content_type = u"application/json; charset=UTF-8"

    def form_invalid(self, form):
        """
        表单校验错误
        :param form:
         :type form: django.forms.form
        :return:
        """
        return self.render_json_response({'success': False,
                                          'msg': get_form_error_message(form)})


class AjaxView(JSONResponseMixin, AjaxResponseMixin, View):
    content_type = u"application/json; charset=UTF-8"


class PermissionRequiredAjaxView(PermissionRequiredMixin, AjaxView):
    """
    有权限要求的AjaxView
    """

    def no_permissions_fail(self, request=None):
        return self.render_json_response({'success': False, 'msg': u'没有权限'})


class LoginRequiredAjaxView(LoginRequiredMixin, AjaxView):
    """
    有登录要求的AjaxView
    """

    def no_permissions_fail(self, request=None):
        return self.render_json_response({'success': False, 'msg': u'请先登录'})


class DialogMixin(object):
    def get_success_url(self):
        return resolve_url('dialog_success')


class NextRedirectMixin(object):
    def get_success_url(self):
        return self.request.GET.get('next', self.success_url)


class OrderableListMixin(olm):
    """
    根据zui.datatable排序
    """

    def get_ordered_queryset(self, queryset=None):
        """
        Augments ``QuerySet`` with order_by statement if possible

        :param QuerySet queryset: ``QuerySet`` to ``order_by``
        :return: QuerySet
        """
        if 'order_by' in self.request.GET:
            return super(OrderableListMixin, self).get_ordered_queryset(queryset)
        try:
            get_order_by = int(self.request.GET.get("index"))

            order_by = self.get_orderable_columns()[get_order_by]
            if not order_by:
                order_by = self.get_orderable_columns_default()
        except:
            order_by = self.get_orderable_columns_default()

        self.order_by = order_by
        self.ordering = 'desc' if order_by.startswith("-") else "asc"

        if order_by and self.request.GET.get("ordering", "asc") == "desc":
            order_by = "-" + order_by if not order_by.startswith("-") else order_by
            self.ordering = "desc"

        return queryset.order_by(order_by)


IMAGE_EXT_NAMES = getattr(settings, 'KINDEDITOR_IMAGE_EXT', ('.jpg', '.png', '.gif', '.bmp'))
FLASH_EXT_NAMES = getattr(settings, 'KINDEDITOR_FLASH_EXT', ('.swf'))
MAX_SIZE = getattr(settings, 'KINDEDITOR_UPLOAD_SIZE', 5) * 1024 * 1024  # 5M
MAX_SIZE_M = MAX_SIZE / 1024 / 1024

storage = default_storage


@csrf_exempt
@require_http_methods(['POST'])
def kindeditor_upload_file(request):
    uploaded_file = request.FILES['imgFile']

    if not uploaded_file.name:
        return HttpResponse(json.dumps({'error': 1, 'message': u'请选择要上传的文件'}))

    ext = os.path.splitext(uploaded_file.name)[1]
    upload_dir = request.GET['dir']
    allowed_exts = None
    if upload_dir == 'image':
        allowed_exts = IMAGE_EXT_NAMES
    elif upload_dir == 'flash':
        allowed_exts = FLASH_EXT_NAMES
    elif upload_dir == 'media':
        pass
    if allowed_exts is not None and ext not in allowed_exts:
        return HttpResponse(json.dumps({'error': 1, 'message': u'不允许的文件格式'}))

    if uploaded_file.size > MAX_SIZE:
        return HttpResponse(json.dumps(
            {'error': 1, 'message': u'上传的文件大小不能超过%sMB' % MAX_SIZE_M}
        ))

    upload_to = os.path.join(datetime.date.today().strftime('kindeditor/upload%Y'),
                             datetime.date.today().strftime("%m%d"))

    file_name = shortuuid.uuid() + ext

    final_name = storage.save(os.path.join(upload_to, file_name), uploaded_file)

    url_name = storage.url(final_name)
    return HttpResponse(json.dumps(
        {'error': 0, 'url': url_name}
    ))


MAX_RESULT = getattr(settings, 'MAX_RESULT', 10)


def tag_suggestion(request):
    """
    tag建议
    @param request:
    @return:
    """
    term = request.GET.get('term')

    tags = [{'id': tag.name, 'text': tag.name}
            for tag in Tag.objects.filter(name__icontains=term)[:MAX_RESULT]]
    return JsonResponse(tags, safe=False)



#coding=utf-8
from django.contrib.auth import get_user_model
from django.contrib.auth.backends import ModelBackend
from django.contrib.auth.models import AbstractUser


class ModelEmailBackend(ModelBackend):
    def authenticate(self, username=None, password=None, **kwargs):
        try:
            user = get_user_model().objects.get(email=username)

            if user.check_password(password):
                return user
        except AbstractUser.DoesNotExist:
            return None
